MethodChannelAndroidRestoreCredentials class

An implementation of AndroidRestoreCredentialsPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearRestoreKey() Future<void>
Deletes the restore key on this device (TYPE_CLEAR_RESTORE_CREDENTIAL).
override
createRestoreKey({required String requestJson, bool preferCloudBackup = true}) Future<String>
Creates a restore key.
override
getRestoreKey({required String requestJson}) Future<String>
Retrieves a restore key.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited